@@ -1,15 +1,10 @@
 
 require 5;
-use 5.008;
-## Anything before 5.8.0 is GIMPY!
 ## This module is to be use()'d only by Pod::Simple::Transcode
 
 package Pod::Simple::TranscodeSmart;
 use strict;
-use Pod::Simple;
 require Encode;
-use vars qw($VERSION );
-$VERSION = '2.29_4';
 
 sub is_dumb  {0}
 sub is_smart {1}
@@ -27,14 +22,11 @@ sub encmodver {
 }
 
 sub make_transcoder {
-  my $e = Encode::find_encoding($_[1]);
+  my($e) = $_[1];
   die "WHAT ENCODING!?!?" unless $e;
   my $x;
   return sub {
-    foreach $x (@_) {
-      $x = $e->decode($x) unless Encode::is_utf8($x);
-    }
-    return;
+    foreach $x (@_) { $x = Encode::decode($e, $x) } return;
   };
 }
 
